# Python API for AirSim

This package contains Python APIs for [Game of Drones: A NeurIPS 2019 Competition](https://github.com/microsoft/AirSim-NeurIPS2019-Drone-Racing), built on [Microsoft AirSim](https://github.com/microsoft/AirSim)

## Dependencies
This package depends on `msgpack` and would automatically install `msgpack-rpc-python` (this may need administrator/sudo prompt):
```
pip install msgpack-rpc-python
```